#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-JngFNlQxNN38c6pcgTv1Xs
key:                  data-functor-logistic-0.0-JngFNlQxNN38c6pcgTv1Xs
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  189716b9dad5e495f5c0997d708f05c3
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-JngFNlQxNN38c6pcgTv1Xs
depends:
    base-4.18.2.1 distributive-0.6.2.1-7xxuUPx5znu9PTcGJv8oEI

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

